summaryrefslogtreecommitdiff
path: root/sc/source/ui/vba/vbarange.cxx
diff options
context:
space:
mode:
authorJulien Nabet <serval2412@yahoo.fr>2014-05-08 00:22:38 +0200
committerJulien Nabet <serval2412@yahoo.fr>2014-05-08 00:22:38 +0200
commit07f14bac2d62cc6dfbb62f8f4f6ba4b7ffea0c6c (patch)
tree0f3f122231a8d075c67c7b0884560974893800ef /sc/source/ui/vba/vbarange.cxx
parent2d5581b49a2f1bbb326a3603def697d1ffe8d63d (diff)
Prefer cppu::UnoType<T>::get() to ::getCppuType((T*)0) part5
Change-Id: Iea68803e0889288d6d7f21e61e731284f0ad1011
Diffstat (limited to 'sc/source/ui/vba/vbarange.cxx')
-rw-r--r--sc/source/ui/vba/vbarange.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/sc/source/ui/vba/vbarange.cxx b/sc/source/ui/vba/vbarange.cxx
index c21ea7d9ee8d..3fa5b4d12a40 100644
--- a/sc/source/ui/vba/vbarange.cxx
+++ b/sc/source/ui/vba/vbarange.cxx
@@ -2185,7 +2185,7 @@ ScVbaRange::CellsHelper( const uno::Reference< ov::XHelperInterface >& xParent,
// Sometimes we might get a float or a double or whatever
// set in the Any, we should convert as appropriate
// #FIXME - perhaps worth turning this into some sort of
// conversion routine e.g. bSuccess = getValueFromAny( nRow, nRowIndex, getCppuType((sal_Int32*)0) )
uno::Any aRowIndexAny = nRowIndex;
if ( aRowIndexAny.hasValue() && !( aRowIndexAny >>= nRow ) )
{
@@ -2193,7 +2193,7 @@ ScVbaRange::CellsHelper( const uno::Reference< ov::XHelperInterface >& xParent,
uno::Any aConverted;
try
{
- aConverted = xConverter->convertTo( aRowIndexAny, getCppuType((sal_Int32*)0) );
+ aConverted = xConverter->convertTo( aRowIndexAny, cppu::UnoType<sal_Int32>::get() );
bIsIndex = ( aConverted >>= nRow );
}
catch( uno::Exception& ) {} // silence any errors
@@ -2222,7 +2222,7 @@ ScVbaRange::CellsHelper( const uno::Reference< ov::XHelperInterface >& xParent,
uno::Any aConverted;
try
{
- aConverted = xConverter->convertTo( aColumnAny, getCppuType((sal_Int32*)0) );
+ aConverted = xConverter->convertTo( aColumnAny, cppu::UnoType<sal_Int32>::get() );
bIsColumnIndex = ( aConverted >>= nColumn );
}
catch( uno::Exception& ) {} // silence any errors
@@ -4509,7 +4509,7 @@ ScVbaRange::AutoFilter( const uno::Any& aField, const uno::Any& Criteria1, const
uno::Reference< script::XTypeConverter > xConverter = getTypeConverter( mxContext );
try
{
- Field = xConverter->convertTo( aField, getCppuType( (sal_Int32*)0 ) );
+ Field = xConverter->convertTo( aField, cppu::UnoType<sal_Int32>::get() );
}
catch( uno::Exception& )
{
@@ -2185,7 +2185,7 @@ ScVbaRange::CellsHelper( const uno::Reference< ov::XHelperInterface >& xParent,
// set in the Any, we should convert as appropriate
// #FIXME - perhaps worth turning this into some sort of
- // conversion routine e.g. bSuccess = getValueFromAny( nRow, nRowIndex, getCppuType((sal_Int32*)0) )
+ // conversion routine e.g. bSuccess = getValueFromAny( nRow, nRowIndex, cppu::UnoType<sal_Int32>::get() )
uno::Any aRowIndexAny = nRowIndex;
if ( aRowIndexAny.hasValue() && !( aRowIndexAny >>= nRow ) )